]> granicus.if.org Git - neomutt/commitdiff
config: rename listener to observer
authorRichard Russon <rich@flatcap.org>
Wed, 15 May 2019 11:25:37 +0000 (12:25 +0100)
committerRichard Russon <rich@flatcap.org>
Thu, 16 May 2019 13:02:45 +0000 (14:02 +0100)
This fits in with the GoF's subject/observer pattern.

32 files changed:
config/bool.c
config/quad.c
config/set.c
config/set.h
index.c
mailbox.c
main.c
menu.c
mutt_history.c
mutt_history.h
mutt_logging.c
mutt_logging.h
mutt_menu.h
protos.h
test/config/account.c
test/config/address.c
test/config/bool.c
test/config/command.c
test/config/common.c
test/config/common.h
test/config/initial.c
test/config/long.c
test/config/magic.c
test/config/mbtable.c
test/config/number.c
test/config/path.c
test/config/quad.c
test/config/regex.c
test/config/set.c
test/config/sort.c
test/config/string.c
test/config/synonym.c

index f583e79af96317f94c13aa00fb658e17bcd43fec..ec9449ace5a59b22a2c20d979ecf6ea893c201da 100644 (file)
@@ -226,7 +226,7 @@ int bool_he_toggle(struct ConfigSet *cs, struct HashElem *he, struct Buffer *err
 
   *(char *) var = !value;
 
-  cs_notify_listeners(cs, he, he->key.strkey, CE_SET);
+  cs_notify_observers(cs, he, he->key.strkey, CE_SET);
   return CSR_SUCCESS;
 }
 
index b0a68bddffdd54d96c68c7f8a214d79bf3361500..15a69e5da53afc7cb5f271c73774a93ef2d327f9 100644 (file)
@@ -242,6 +242,6 @@ int quad_he_toggle(struct ConfigSet *cs, struct HashElem *he, struct Buffer *err
 
   *(char *) var = quad_toggle(value);
 
-  cs_notify_listeners(cs, he, he->key.strkey, CE_SET);
+  cs_notify_observers(cs, he, he->key.strkey, CE_SET);
   return CSR_SUCCESS;
 }
index 051c435fe51de437c0f636fc97cabf15d19e2bac..4389d753ed5993d0ee1864a33e269af13408740a 100644 (file)
@@ -308,74 +308,74 @@ struct HashElem *cs_inherit_variable(const struct ConfigSet *cs,
 }
 
 /**
- * cs_add_listener - Add a listener (callback function)
+ * cs_add_observer - Add a observer (callback function)
  * @param cs Config items
- * @param fn Listener callback function
+ * @param fn Observer callback function
  */
-void cs_add_listener(struct ConfigSet *cs, cs_listener fn)
+void cs_add_observer(struct ConfigSet *cs, cs_observer fn)
 {
   if (!cs || !fn)
     return;
 
-  for (size_t i = 0; i < mutt_array_size(cs->listeners); i++)
+  for (size_t i = 0; i < mutt_array_size(cs->observers); i++)
   {
-    if (cs->listeners[i] == fn)
+    if (cs->observers[i] == fn)
     {
-      mutt_debug(LL_DEBUG1, "Listener was already registered\n");
+      mutt_debug(LL_DEBUG1, "Observer was already registered\n");
       return;
     }
   }
 
-  for (size_t i = 0; i < mutt_array_size(cs->listeners); i++)
+  for (size_t i = 0; i < mutt_array_size(cs->observers); i++)
   {
-    if (!cs->listeners[i])
+    if (!cs->observers[i])
     {
-      cs->listeners[i] = fn;
+      cs->observers[i] = fn;
       return;
     }
   }
 }
 
 /**
- * cs_remove_listener - Remove a listener (callback function)
+ * cs_remove_observer - Remove a observer (callback function)
  * @param cs Config items
- * @param fn Listener callback function
+ * @param fn Observer callback function
  */
-void cs_remove_listener(struct ConfigSet *cs, cs_listener fn)
+void cs_remove_observer(struct ConfigSet *cs, cs_observer fn)
 {
   if (!cs || !fn)
     return;
 
-  for (size_t i = 0; i < mutt_array_size(cs->listeners); i++)
+  for (size_t i = 0; i < mutt_array_size(cs->observers); i++)
   {
-    if (cs->listeners[i] == fn)
+    if (cs->observers[i] == fn)
     {
-      cs->listeners[i] = NULL;
+      cs->observers[i] = NULL;
       return;
     }
   }
-  mutt_debug(LL_DEBUG1, "Listener wasn't registered\n");
+  mutt_debug(LL_DEBUG1, "Observer wasn't registered\n");
 }
 
 /**
- * cs_notify_listeners - Notify all listeners of an event
+ * cs_notify_observers - Notify all observers of an event
  * @param cs   Config items
  * @param he   HashElem representing config item
  * @param name Name of config item
  * @param ev   Type of event
  */
-void cs_notify_listeners(const struct ConfigSet *cs, struct HashElem *he,
+void cs_notify_observers(const struct ConfigSet *cs, struct HashElem *he,
                          const char *name, enum ConfigEvent ev)
 {
   if (!cs || !he || !name)
     return;
 
-  for (size_t i = 0; i < mutt_array_size(cs->listeners); i++)
+  for (size_t i = 0; i < mutt_array_size(cs->observers); i++)
   {
-    if (!cs->listeners[i])
+    if (!cs->observers[i])
       return;
 
-    cs->listeners[i](cs, he, name, ev);
+    cs->observers[i](cs, he, name, ev);
   }
 }
 
@@ -422,7 +422,7 @@ int cs_he_reset(const struct ConfigSet *cs, struct HashElem *he, struct Buffer *
   }
 
   if ((CSR_RESULT(rc) == CSR_SUCCESS) && !(rc & CSR_SUC_NO_CHANGE))
-    cs_notify_listeners(cs, he, he->key.strkey, CE_RESET);
+    cs_notify_observers(cs, he, he->key.strkey, CE_RESET);
   return rc;
 }
 
@@ -485,7 +485,7 @@ int cs_he_initial_set(const struct ConfigSet *cs, struct HashElem *he,
   if (CSR_RESULT(rc) != CSR_SUCCESS)
     return rc;
 
-  cs_notify_listeners(cs, he, he->key.strkey, CE_INITIAL_SET);
+  cs_notify_observers(cs, he, he->key.strkey, CE_INITIAL_SET);
   return CSR_SUCCESS;
 }
 
@@ -630,7 +630,7 @@ int cs_he_string_set(const struct ConfigSet *cs, struct HashElem *he,
     he->type = i->parent->type | DT_INHERITED;
   }
   if (!(rc & CSR_SUC_NO_CHANGE))
-    cs_notify_listeners(cs, he, he->key.strkey, CE_SET);
+    cs_notify_observers(cs, he, he->key.strkey, CE_SET);
   return rc;
 }
 
@@ -772,7 +772,7 @@ int cs_he_native_set(const struct ConfigSet *cs, struct HashElem *he,
     if (he->type & DT_INHERITED)
       he->type = cdef->type | DT_INHERITED;
     if (!(rc & CSR_SUC_NO_CHANGE))
-      cs_notify_listeners(cs, he, cdef->name, CE_SET);
+      cs_notify_observers(cs, he, cdef->name, CE_SET);
   }
 
   return rc;
@@ -826,7 +826,7 @@ int cs_str_native_set(const struct ConfigSet *cs, const char *name,
     if (he->type & DT_INHERITED)
       he->type = cdef->type | DT_INHERITED;
     if (!(rc & CSR_SUC_NO_CHANGE))
-      cs_notify_listeners(cs, he, cdef->name, CE_SET);
+      cs_notify_observers(cs, he, cdef->name, CE_SET);
   }
 
   return rc;
index 74e07d625d8a5a8dbda89f96762902559415d225..82cc98ad3fd49137bfd1bc7b6dd4323768a9c05f 100644 (file)
@@ -62,23 +62,23 @@ enum ConfigEvent
 #define CSR_RESULT(x) ((x) & CSR_RESULT_MASK)
 
 /**
- * enum CsListenerAction - Config Listener responses
+ * enum CsObserverAction - Config Observer responses
  */
-enum CsListenerAction
+enum CsObserverAction
 {
-  CSLA_CONTINUE = 1, ///< Continue notifying listeners
-  CSLA_STOP,         ///< Stop notifying listeners
+  CSOA_CONTINUE = 1, ///< Continue notifying observers
+  CSOA_STOP,         ///< Stop notifying observers
 };
 
 /**
- * typedef cs_listener - Listen for config changes
+ * typedef cs_observer - Listen for config changes
  * @param cs   Config items
  * @param he   HashElem representing config item
  * @param name Name of the config item
  * @param ev   Event type, e.g. #CE_SET
  * @retval true Continue notifying
  */
-typedef bool    (*cs_listener)   (const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+typedef bool    (*cs_observer)   (const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 /**
  * typedef cs_validator - Validate the "charset" config variable
  * @param cs    Config items
@@ -197,7 +197,7 @@ struct ConfigSet
 {
   struct Hash *hash;              /**< HashTable storing the config itesm */
   struct ConfigSetType types[18]; /**< All the defined config types */
-  cs_listener listeners[8];       /**< Listeners for notifications of changes to config items */
+  cs_observer observers[8];       /**< Observers for notifications of changes to config items */
 };
 
 struct ConfigSet *cs_new(size_t size);
@@ -211,9 +211,9 @@ bool             cs_register_type(struct ConfigSet *cs, unsigned int type, const
 bool             cs_register_variables(const struct ConfigSet *cs, struct ConfigDef vars[], int flags);
 struct HashElem *cs_inherit_variable(const struct ConfigSet *cs, struct HashElem *parent, const char *name);
 
-void cs_add_listener(struct ConfigSet *cs, cs_listener fn);
-void cs_remove_listener(struct ConfigSet *cs, cs_listener fn);
-void cs_notify_listeners(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+void cs_add_observer(struct ConfigSet *cs, cs_observer fn);
+void cs_remove_observer(struct ConfigSet *cs, cs_observer fn);
+void cs_notify_observers(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 
 int      cs_he_initial_get (const struct ConfigSet *cs, struct HashElem *he,                    struct Buffer *result);
 int      cs_he_initial_set (const struct ConfigSet *cs, struct HashElem *he, const char *value, struct Buffer *err);
--- a/mailbox.c
+++ b/mailbox.c
@@ -552,7 +552,7 @@ void mutt_mailbox_next(struct Mailbox *m_cur, char *s, size_t slen)
 }
 
 /**
- * mutt_mailbox_changed - Notify listeners of a change to a Mailbox
+ * mutt_mailbox_changed - Notify observers of a change to a Mailbox
  * @param m      Mailbox
  * @param action Change to Mailbox
  */
diff --git a/main.c b/main.c
index 1401c86851fb340faa1c3208b424e2e36ef4081e..6ab3751e8025a26189c29af95cb9be5fa7a51a44 100644 (file)
--- a/main.c
+++ b/main.c
@@ -824,10 +824,10 @@ int main(int argc, char *argv[], char *envp[])
     goto main_ok; // TEST22: neomutt -B
   }
 
-  cs_add_listener(Config, mutt_hist_listener);
-  cs_add_listener(Config, mutt_log_listener);
-  cs_add_listener(Config, mutt_menu_listener);
-  cs_add_listener(Config, mutt_reply_listener);
+  cs_add_observer(Config, mutt_hist_observer);
+  cs_add_observer(Config, mutt_log_observer);
+  cs_add_observer(Config, mutt_menu_observer);
+  cs_add_observer(Config, mutt_reply_observer);
 
   if (sendflags & SEND_POSTPONED)
   {
--- a/protos.h
+++ b/protos.h
@@ -86,7 +86,7 @@ int mutt_is_quote_line(char *buf, regmatch_t *pmatch);
 int wcscasecmp(const wchar_t *a, const wchar_t *b);
 #endif
 
-bool mutt_reply_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool mutt_reply_observer(const struct ConfigSet *cs, struct HashElem *he,
                          const char *name, enum ConfigEvent ev);
 
 #endif /* MUTT_PROTOS_H */
index 7bc823ab5bf08d7f236babfbf1af50692a75933a..278aa56abfd86f8ac6d53a1fb8d7130db675cca7 100644 (file)
@@ -60,7 +60,7 @@ void config_account(void)
 
   set_list(cs);
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   const char *account = "damaged";
   const char *BrokenVarStr[] = {
index 22433aea479f1fc0268c90622aa5d840eb929584..460e871f6774a3effee2f30c7997e5fc3dafcf93 100644 (file)
@@ -611,7 +611,7 @@ void config_address(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index b52845fbeb93a101bd6c91a0e81d032b10bc1e2e..8b76ef1c4e8e9287d93ecdd92df5c6499eaad770 100644 (file)
@@ -765,7 +765,7 @@ void config_bool(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 2a3ef6e297e20ed74fd133325eee25de3877847d..9f165e7b3b5df8b7184810ab8d946234eec20d43 100644 (file)
@@ -638,7 +638,7 @@ void config_command(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 081b9b91e30763daeff87453f5d6b1f3c9462f0f..5bd26f6deb7eb62bd519fd0dcd74efd63b34dfce 100644 (file)
@@ -81,7 +81,7 @@ void short_line(void)
   TEST_MSG("%s\n", line + 40);
 }
 
-bool log_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool log_observer(const struct ConfigSet *cs, struct HashElem *he,
                   const char *name, enum ConfigEvent ev)
 {
   struct Buffer result;
index 21029e93bedd434df5c74f87ed578597f9e35eea..0321ff2e5cc3c8a6afbcacea74b575ea02d944a5 100644 (file)
@@ -40,7 +40,7 @@ int validator_fail   (const struct ConfigSet *cs, const struct ConfigDef *cdef,
 
 void log_line(const char *fn);
 void short_line(void);
-bool log_listener(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+bool log_observer(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 void set_list(const struct ConfigSet *cs);
 void cs_dump_set(const struct ConfigSet *cs);
 
index acb9087e23201e531b54433709f68f08bb915143..0a6379378541fabfd599cb3618a3f7c28d4bc279 100644 (file)
@@ -103,7 +103,7 @@ void config_initial(void)
   if (!cs_register_variables(cs, Vars, 0))
     return;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index e57313fd01ac181b322b047d48e703d1e5e1efe3..1ae7f1e0db4adf99de280929d1e523afabf65787 100644 (file)
@@ -589,7 +589,7 @@ void config_long(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 97701864ca574d18115d7f653438414856531965..77a18e4300ef3bf8cf8fa811679df2d84a62f338 100644 (file)
@@ -576,7 +576,7 @@ void config_magic(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index e350e3efac790a71d225e2c226041b25a767e538..98954cef9f44104c0d0d82ee311ff2e88369cebc 100644 (file)
@@ -627,7 +627,7 @@ void config_mbtable(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 7458c2837e222fc9ddb8e8c1e377655d54f23508..50ea8ce611597b8fac1ea45f83fa0442751a7acc 100644 (file)
@@ -608,7 +608,7 @@ void config_number(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index a63bc8793cff4435b78ffc5265c1569e8dbcc4e1..1cc586279f6fe9710d4138af4ecbe9d9bb701998 100644 (file)
@@ -638,7 +638,7 @@ void config_path(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index c58f8a61de9da25557e305b32de605e759a1692b..9ea9b4618051d0720bab5aa8b74afbeb9eb2a749 100644 (file)
@@ -703,7 +703,7 @@ void config_quad(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 5a38f36c69a295e93c33399effe485048c6788ae..f456af8ff5cff9d27b025f19637f7a50e1dda2dd 100644 (file)
@@ -687,7 +687,7 @@ void config_regex(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 557807ad176bdc6d3a2ca388529313b6f92827ec..be5611b9f82502326f7e7aa8438b634dcee951b3 100644 (file)
@@ -88,20 +88,20 @@ bool degenerate_tests(struct ConfigSet *cs)
   TEST_CHECK_(1, "cs_init(NULL, 100)");
   cs_free(NULL);
   TEST_CHECK_(1, "cs_free(NULL)");
-  cs_add_listener(cs, NULL);
-  TEST_CHECK_(1, "cs_add_listener(cs, NULL)");
-  cs_add_listener(NULL, log_listener);
-  TEST_CHECK_(1, "cs_add_listener(NULL, log_listener)");
-  cs_remove_listener(cs, NULL);
-  TEST_CHECK_(1, "cs_remove_listener(cs, NULL)");
-  cs_remove_listener(NULL, log_listener);
-  TEST_CHECK_(1, "cs_remove_listener(NULL, log_listener)");
-  cs_notify_listeners(NULL, he, "apple", CE_SET);
-  TEST_CHECK_(1, "cs_notify_listeners(NULL, he, \"apple\", CE_SET)");
-  cs_notify_listeners(cs, NULL, "apple", CE_SET);
-  TEST_CHECK_(1, "cs_notify_listeners(cs, NULL, \"apple\", CE_SET)");
-  cs_notify_listeners(cs, he, NULL, CE_SET);
-  TEST_CHECK_(1, "cs_notify_listeners(cs, he, NULL, CE_SET)");
+  cs_add_observer(cs, NULL);
+  TEST_CHECK_(1, "cs_add_observer(cs, NULL)");
+  cs_add_observer(NULL, log_observer);
+  TEST_CHECK_(1, "cs_add_observer(NULL, log_observer)");
+  cs_remove_observer(cs, NULL);
+  TEST_CHECK_(1, "cs_remove_observer(cs, NULL)");
+  cs_remove_observer(NULL, log_observer);
+  TEST_CHECK_(1, "cs_remove_observer(NULL, log_observer)");
+  cs_notify_observers(NULL, he, "apple", CE_SET);
+  TEST_CHECK_(1, "cs_notify_observers(NULL, he, \"apple\", CE_SET)");
+  cs_notify_observers(cs, NULL, "apple", CE_SET);
+  TEST_CHECK_(1, "cs_notify_observers(cs, NULL, \"apple\", CE_SET)");
+  cs_notify_observers(cs, he, NULL, CE_SET);
+  TEST_CHECK_(1, "cs_notify_observers(cs, he, NULL, CE_SET)");
 
   if (!TEST_CHECK(cs_register_type(NULL, DT_NUMBER, &cst_dummy) == false))
     return false;
@@ -229,10 +229,10 @@ void config_set(void)
   if (!TEST_CHECK(cs != NULL))
     return;
 
-  cs_add_listener(cs, log_listener);
-  cs_add_listener(cs, log_listener); /* dupe */
-  cs_remove_listener(cs, log_listener);
-  cs_remove_listener(cs, log_listener); /* non-existant */
+  cs_add_observer(cs, log_observer);
+  cs_add_observer(cs, log_observer); /* dupe */
+  cs_remove_observer(cs, log_observer);
+  cs_remove_observer(cs, log_observer); /* non-existant */
 
   const struct ConfigSetType cst_dummy = {
     "dummy", NULL, NULL, NULL, NULL, NULL, NULL,
index 72d1337402275391c0ee2d2ff6e96e003d15d4ed..d8443901622430980609a51d667e8b61d15dbbbe 100644 (file)
@@ -733,7 +733,7 @@ void config_sort(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 9b2e51912d98ad70da47c8b621204fb5356ed506..7b529c596cd047e905d51738a3b580249734bcb4 100644 (file)
@@ -638,7 +638,7 @@ void config_string(void)
     return;
   dont_fail = false;
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
 
index 7ed471e0121d834505c212eb62a87e4b6aa82159..6b56017c624196fbf4bc32a4bc1aa0fe96d2ef09 100644 (file)
@@ -203,7 +203,7 @@ void config_synonym(void)
     return;
   }
 
-  cs_add_listener(cs, log_listener);
+  cs_add_observer(cs, log_observer);
 
   set_list(cs);
diff --git a/index.c b/index.c
index d87f1e11d5cd5ac5cd5743cc09e576ec015d91be..d5b32dd61784f5d68f5b3f0ca5f19e3265f29ec9 100644 (file)
--- a/index.c
+++ b/index.c
@@ -3663,9 +3663,9 @@ void mutt_set_header_color(struct Mailbox *m, struct Email *e)
 }
 
 /**
* mutt_reply_listener - Listen for config changes to "reply_regex" - Implements ::cs_listener()
  */
-bool mutt_reply_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool mutt_reply_observer(const struct ConfigSet *cs, struct HashElem *he,
                          const char *name, enum ConfigEvent ev)
 {
   if (mutt_str_strcmp(name, "reply_regex") != 0)
@@ -3663,9 +3663,9 @@ void mutt_set_header_color(struct Mailbox *m, struct Email *e)
 
 /**
- * mutt_reply_listener - Listen for config changes to "reply_regex" - Implements ::cs_listener()
+ * mutt_reply_observer - Listen for config changes to "reply_regex" - Implements ::cs_observer()
  */
index 062e391c247d4f0adc60eda852cd4aa474f52f40..787d60814a932949f515a40e04d69d72e086d647 100644 (file)
diff --git a/menu.c b/menu.c
index d1d403029c9af054cca9b6ed0d7eb6c3e4f670a8..e25ed375eb960beef6f66e5d14617fc8db98fa1b 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -1591,9 +1591,9 @@ int mutt_menu_loop(struct Menu *menu)
 }
 
 /**
* mutt_menu_listener - Listen for config changes affecting the menu - Implements ::cs_listener()
  */
-bool mutt_menu_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool mutt_menu_observer(const struct ConfigSet *cs, struct HashElem *he,
                         const char *name, enum ConfigEvent ev)
 {
   const struct ConfigDef *cdef = he->data;
index 01c875a0fa7b13a8e9cf6b0e7d0869c8bc316edf..38726adf3709d45441b3c08a7574ea1ceb6d8914 100644 (file)
@@ -144,9 +144,9 @@ void mutt_hist_complete(char *buf, size_t buflen, enum HistoryClass hclass)
 }
 
 /**
* mutt_hist_listener - Listen for config changes affecting the history - Implements ::cs_listener()
  */
-bool mutt_hist_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool mutt_hist_observer(const struct ConfigSet *cs, struct HashElem *he,
                         const char *name, enum ConfigEvent ev)
 {
   if (mutt_str_strcmp(name, "history") != 0)
index 8f16cf6a62ffdde81386db50c729b641db5b7d5e..587a63605baf68d86fe299ad64aee09294a1efdb 100644 (file)
@@ -27,6 +27,6 @@
 #include "mutt/mutt.h"
 
 void mutt_hist_complete(char *buf, size_t buflen, enum HistoryClass hclass);
-bool mutt_hist_listener(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+bool mutt_hist_observer(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 
 #endif /* MUTT_MUTT_HISTORY_H */
index 007aad664e12bc65ea835fadb7964707b1d8f376..1ffe7637b68824c27735d0ec4c4b2ea9375a20f7 100644 (file)
@@ -335,9 +335,9 @@ int level_validator(const struct ConfigSet *cs, const struct ConfigDef *cdef,
 }
 
 /**
* mutt_log_listener - Listen for config changes affecting the log file - Implements ::cs_listener()
  */
-bool mutt_log_listener(const struct ConfigSet *cs, struct HashElem *he,
+bool mutt_log_observer(const struct ConfigSet *cs, struct HashElem *he,
                        const char *name, enum ConfigEvent ev)
 {
   if (mutt_str_strcmp(name, "debug_file") == 0)
index 312ce6af3cc6f2f1076150cc1b2c8247a5a706d5..ad41a6a505671350688a48e1696c8bd494da8fce 100644 (file)
@@ -37,7 +37,7 @@ int  mutt_log_start(void);
 void mutt_log_stop(void);
 int  mutt_log_set_level(int level, bool verbose);
 int  mutt_log_set_file(const char *file, bool verbose);
-bool mutt_log_listener(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+bool mutt_log_observer(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 int  level_validator(const struct ConfigSet *cs, const struct ConfigDef *cdef, intptr_t value, struct Buffer *err);
 
 void mutt_clear_error(void);
index 1a54a4f1e620ed2a2b6dace76f78d3e5e467a75d..7e31805a630313b0a914fdf510565e08737538bc 100644 (file)
@@ -189,6 +189,6 @@ void         mutt_menu_set_current_redraw(MuttRedrawFlags redraw);
 void         mutt_menu_set_redraw_full(int menu_type);
 void         mutt_menu_set_redraw(int menu_type, MuttRedrawFlags redraw);
 
-bool mutt_menu_listener(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
+bool mutt_menu_observer(const struct ConfigSet *cs, struct HashElem *he, const char *name, enum ConfigEvent ev);
 
 #endif /* MUTT_MENU_H */
index b51420b3d956ad1f0d9208c36a4aca114954dd82..29f6e579cdc266a3e16b055ef706771fc69ca6ee 100644 (file)
@@ -1591,9 +1591,9 @@ int mutt_menu_loop(struct Menu *menu)
 
 /**
- * mutt_menu_listener - Listen for config changes affecting the menu - Implements ::cs_listener()
+ * mutt_menu_observer - Listen for config changes affecting the menu - Implements ::cs_observer()
  */
@@ -144,9 +144,9 @@ void mutt_hist_complete(char *buf, size_t buflen, enum HistoryClass hclass)
 
 /**
- * mutt_hist_listener - Listen for config changes affecting the history - Implements ::cs_listener()
+ * mutt_hist_observer - Listen for config changes affecting the history - Implements ::cs_observer()
  */
@@ -335,9 +335,9 @@ int level_validator(const struct ConfigSet *cs, const struct ConfigDef *cdef,
 
 /**
- * mutt_log_listener - Listen for config changes affecting the log file - Implements ::cs_listener()
+ * mutt_log_observer - Listen for config changes affecting the log file - Implements ::cs_observer()
  */